SoilSensorConfig class

Configuration for a Modbus soil sensor, mirrors native SoilSensorConfig.

Constructors

SoilSensorConfig({int slaveId = 1, int startAddress = 0x0000, int registerCount = 8, int responseDelayMs = 300})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
registerCount → int
final
responseDelayMs → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slaveId → int
final
startAddress → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited