UsbDevice class

Constructors

UsbDevice({required int vendorId, required int productId, String? manufacturer})
const
UsbDevice.fromJson(String source)
factory
UsbDevice.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
manufacturer → String?
final
productId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vendorId → int
final

Methods

copyWith({int? vendorId, int? productId, String? manufacturer}) → UsbDevice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override